<template>
  <a-card :bordered='false' :class="'cust-erp-sub-tab'">
    <!-- 查询区域 -->
    <div class='table-page-search-wrapper'>
      <a-form layout='inline' @keyup.enter.native='searchQuery'>
        <a-row :gutter='24'>
        </a-row>
      </a-form>
    </div>
    <!-- 查询区域-END -->

    <!-- 操作按钮区域 -->
    <div class='table-operator' v-if="repairOrderSelectionRows.length == 1 && repairOrderSelectionRows[0].auditStatus == 'notSubmitted'">
      <a-button @click='handleAdd' type='primary' icon='plus'>新增</a-button>
      <a-dropdown v-if='selectedRowKeys.length > 0'>
        <a-menu slot='overlay'>
          <a-menu-item key='1' @click='batchDel'>
            <a-icon type='delete' />
            删除
          </a-menu-item>
        </a-menu>
        <a-button style='margin-left: 8px'> 批量操作
          <a-icon type='down' />
        </a-button>
      </a-dropdown>
    </div>

    <!-- table区域-begin -->
    <div>
      <!-- <div class='ant-alert ant-alert-info' style='margin-bottom: 16px;'>
        <i class='anticon anticon-info-circle ant-alert-icon'></i> 已选择 <a
        style='font-weight: 600'>{{ selectedRowKeys.length }}</a>项
        <a style='margin-left: 24px' @click='onClearSelected'>清空</a>
      </div> -->

      <a-table
        ref='table'
        size='middle'
        bordered
        rowKey='id'
        :scroll='{x:true}'
        :columns='columns'
        :dataSource='dataSource'
        :pagination='ipagination'
        :loading='loading'
        @change='handleTableChange'>

        <template slot='htmlSlot' slot-scope='text'>
          <div v-html='text'></div>
        </template>


        <span slot='action' slot-scope='text, record'>
          <a @click='handleEdit(record)'>编辑</a>
          <a-divider type='vertical' />
          <a-popconfirm title='确定删除吗?' @confirm='() => handleDelete(record.id)'>
            <a>删除</a>
          </a-popconfirm>
        </span>

      </a-table>
    </div>
    <repair-order-actual-material-report-model
      ref='modalForm'
      @ok='modalFormOk'
      :reportAfterRepairId = "this.mainId"
    >
    </repair-order-actual-material-report-model>
  </a-card>
</template>

<script>

import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import RepairOrderActualMaterialReportModel   from '../repairOrderFinishedReport/modules/RepairOrderActualMaterialReportModel.vue'

export default {
  name: 'RepairOrderActualMaterialReport',
  mixins: [JeecgListMixin],
  components: { RepairOrderActualMaterialReportModel },
  props: {
    mainId:{
        type:String,
        default:'',
        required:false
      },
  },
  watch: {
    mainId: {
      immediate: true,
      handler(val) {
        console.log(val)
        if (!this.mainId) {

          this.clearList()
        } else {
          this.queryParam['reportAfterRepairId'] = val
          this.loadData(1)
        }
      }
    }
  },
  data() {
    return {
      description: '维修工单管理页面',
      disableMixinCreated: true,
      repairOrderSelectionRows:[],
      // 表头
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          width: 60,
          align: 'center',
          customRender: function(t, r, index) {
            return parseInt(index) + 1
          }
        },
        {
          title: '领料出库单',
          dataIndex: 'outboundNum',
          align: 'center',
          width: 150
        },
        {
          title: '备件编码',
          dataIndex: 'sparePartNum',
          align: 'center'

        },
        {
          title: '备件名称',
          dataIndex: 'sparePartName',
          align: 'center'

        },
        {
          title: '规格',
          dataIndex: 'sparePartSpecification',
          align: 'center',
          width: 250
        },
        {
          title: '型号',
          dataIndex: 'sparePartModel',
          align: 'center'
        },
        {
          title: '制造商',
          dataIndex: 'constructorName',
          align: 'center'
        },
        {
          title: '主单位',
          dataIndex: 'mainUnitId_dictText',
          align: 'center'

        },
        {
          title: '数量',
          dataIndex: 'actualQuantity',
          align: 'center'

        },
        {
          title: '操作',
          dataIndex: 'action',
          align: 'center',
          fixed: 'right',
          width: 147,
          scopedSlots: { customRender: 'action' }
        }
      ],
      url: {
        list: '/eam/reportAfterRepair/listRepairOrderActualMaterialByMainId',
        delete: '/eam/repairOrder/deleteRepairOrderActualMaterial',
        deleteBatch: '/eam/repairOrder/deleteBatchRepairOrderActualMaterial',
        exportXlsUrl: '/eam/repairOrder/exportRepairOrderActualMaterial',
        importUrl: '/eam/repairOrder/importRepairOrderActualMaterial'
      },
      dictOptions: {}
    }
  },
  created() {
  },
  computed: {
    importExcelUrl() {
      return `${window._CONFIG['domianURL']}/${this.url.importUrl}/${this.mainId}`
    }
  },
  mounted() {
    this.$bus.$on('repairOrderSelectionRows', (data) => {
      this.repairOrderSelectionRows = data
    })
  },
  methods: {
    clearList() {
      this.dataSource = []
      this.selectedRowKeys = []
      this.ipagination.current = 1
    },
    handleAdd: function() {
      this.$refs.modalForm.add(this.repairOrderSelectionRows)
      this.$refs.modalForm.title = '新增'
      this.$refs.modalForm.disableSubmit = false
    },
  }
}
</script>
<style scoped>
@import '~@assets/less/common.less';
</style>
